Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type BytesWriter ¶
type BytesWriter struct {
// contains filtered or unexported fields
}
BytesWriter is a simple wrapper around a byte slice that implements io.Writer.
func (*BytesWriter) Bytes ¶
func (w *BytesWriter) Bytes() []byte
Bytes returns the written portion of the byte slice.
func (*BytesWriter) Init ¶
func (w *BytesWriter) Init(buf []byte)
Init initializes the BytesWriter with a byte slice.
type LimitedReader ¶
A LimitedReader reads from R but limits the amount of data returned to just N bytes. Each call to Read updates N to reflect the new amount remaining. Read returns EOF when N <= 0 or when the underlying R returns EOF. See std io.LimitedReader for details.
Click to show internal directories.
Click to hide internal directories.